Credits
=======

- Gene Diaz, stopwords compilation, npm and bower packages
- Arthit Suriyawongkul, pip package

Below are the sources of this collection.
- [Link Assistant](http://www.link-assistant.com/seo-stop-words.html)
- [Lextek Onix](http://www.lextek.com/manuals/onix/stopwords1.html)
- [Snowball Tartarus](http://snowball.tartarus.org/algorithms/english/stop.txt)
- [Webconfs](http://www.webconfs.com/stop-words.php)
- [99Webtools](http://99webtools.com/blog/list-of-english-stop-words)
- [University of Glasgow Linguistics](http://ir.dcs.gla.ac.uk/resources/linguistic_utils/stop_words)
- [SEO Book](http://tools.seobook.com/general/keyword-density/stop_words.txt)
- [Nat'l Center for Biotech Info](http://www.ncbi.nlm.nih.gov/books/NBK3827/table/pubmedhelp.T43)
- [Ranks NL](http://www.ranks.nl/stopwords)
- [Stop-words](http://code.google.com/p/stop-words)
- [Geonetwork](http://github.com/geonetwork/core-geonetwork)
- [JS-StopWord](https://github.com/mirzaasif/JS-StopWord)
- [WP Arabic Stopwords](https://github.com/nash-ye/WP-Arabic-Stopwords)
- [Stopwords JSON by Peter Graham](https://github.com/6/stopwords-json)
- [Stopwords by Raif Tolga Korkunckaya](https://github.com/tkorkunckaya/Turkish-Stopwords)
- [Stopwords by Vahid Kharazi](https://github.com/kharazi/persian-stopwords)
- [Stopwords by Huned Botee](https://github.com/huned/node-stopwords)
- [Stopwords by Benjamin Balet](https://github.com/bbalet/stopwords)
- [Stopwords by Leonard Aukea](https://github.com/LeonardAukea/StopWords)
- [Stopwords by John Bresnik](https://github.com/brez/stopwords)
- [Stopwords by Van-Duyet Le](https://github.com/stopwords)
- [Stopword by Fergus McDowall](https://github.com/fergiemcdowall/stopword)
- [Lunr Languages](https://github.com/MihaiValentin/lunr-languages)
- [Stopwords-filter](https://github.com/brenes/stopwords-filter)
- [Text Normalize](https://github.com/touv/text_normalize)
- [Language Resources](https://github.com/ebertti/language-resource)
- [Grk Stoplist](https://github.com/pharos-alexandria/grk-stoplist)
- [Nolimit Kamus](https://github.com/nolimitid/nolimit-kamus)
- [Baidu Stopwords](http://www.baiduguide.com/baidu-stopwords)
